# -*- coding: utf-8 -*-

"""Run landmark experiments."""

from .cli import experiments

if __name__ == "__main__":
    experiments()
